<h1>{{data.title}}</h1>

<a href="{% url 'core_dashboard_workspaces' %}" class="btn btn-secondary back-to-previous float-right">
     <i class="fas fa-arrow-left"></i> Previous page
</a>

{% block box_body %}
    <div class="tab-content">
        {% include data.template with objects=data.user_data group='user' %}
    </div>
{% endblock %}

